%define oname    OpenJPEG

%define major    7
%define lib_name %mklibname openjp2_ %{major}
%define lib_dev  %mklibname %{name} -d

Name:           openjpeg2
Version:        2.5.0
%define subrel 2
Release:        %mkrel 1
Summary:        An open-source JPEG 2000 codec
License:        BSD
Group:          System/Libraries
Url:            http://www.openjpeg.org/
Source0:        https://github.com/uclouvain/openjpeg/archive/v%{version}/openjpeg-%{version}.tar.gz
Patch0:         openjpeg2-remove-thirdparty.patch
#
# Security Patches
# P100 -> ...
#
Patch101:       heap-buffer-overflow.patch
Patch102:       CVE-2023-39327.patch
Patch103:       98592ee6d6904f1b48e8207238779b89a63befa2.patch
Patch104:       e492644fbded4c820ca55b5e50e598d346e850e8.patch

BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  cmake
BuildRequires:  doxygen

%description
The OpenJPEG library is an open-source JPEG 2000 codec written in C
language. It has been developed in order to promote the use of JPEG
2000, the new still-image compression standard from the Joint
Photographic Experts Group (JPEG).

%package -n     %{lib_name}
Summary:        %{oname} library
Group:          System/Libraries

%description -n %{lib_name}
This package contains the library needed to run programs dynamically
linked with the %{oname} library.

The OpenJPEG library is an open-source JPEG 2000 codec written in C
language. It has been developed in order to promote the use of JPEG
2000, the new still-image compression standard from the Joint
Photographic Experts Group (JPEG).

%package -n     %{lib_dev}
Summary:        Development tools for programs using the %{oname} library
Group:          Development/C
Requires:       %{lib_name} = %{version}
Requires:       %{name} = %{version}
Provides:       %{name}-devel = %{version}-%{release}
Conflicts:      openjpeg-devel < 2.0.0

%description -n %{lib_dev}
This package contains the header files and libraries needed for
developing programs using the %{oname} library.

The OpenJPEG library is an open-source JPEG 2000 codec written in C
language. It has been developed in order to promote the use of JPEG
2000, the new still-image compression standard from the Joint
Photographic Experts Group (JPEG).

%prep
%setup -qn openjpeg-%{version}
%autopatch -p1

%build
%cmake \
  -DOPENJPEG_INSTALL_BIN_DIR:PATH=%{_bindir} \
  -DOPENJPEG_INSTALL_DATA_DIR:PATH=%{_datadir} \
  -DOPENJPEG_INSTALL_LIB_DIR:PATH=%{_lib} \
  -DBUILD_DOC=ON
%cmake_build

%install
%cmake_install

rm -rf %{buildroot}%{_docdir}
rm -rf %{buildroot}%{_libdir}/libopenjp2.a

%files
%doc AUTHORS.md CHANGELOG.md NEWS.md README.md THANKS.md
%license LICENSE
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{lib_name}
%{_libdir}/*.so.%{major}
%{_libdir}/*.so.%{version}

%files -n %{lib_dev}
%{_includedir}/*
%{_mandir}/man3/*
%{_libdir}/*.so
%{_libdir}/openjpeg-*/
%{_libdir}/pkgconfig/libopenjp2.pc


%changelog
* Fri Jan 10 2025 ns80 <ns80> 2.5.0-1.2.mga9
+ Revision: 2136968
- add upstream patches for CVE-2024-5682[67] (mga#33905)
- add patch from Ubuntu for CVE-2023-39327 (mga#33595)

* Sat Sep 03 2022 papoteur <papoteur> 2.5.0-1.mga9
+ Revision: 1883603
- new 2.5.0

* Fri Apr 01 2022 ns80 <ns80> 2.4.0-5.mga9
+ Revision: 1839042
- add patch from Fedora for CVE-2022-1122 (mga#30229)

* Tue Mar 29 2022 umeabot <umeabot> 2.4.0-4.mga9
+ Revision: 1831232
- Mageia 9 Mass Rebuild

* Sun Jun 27 2021 luigiwalser <luigiwalser> 2.4.0-3.mga9
+ Revision: 1734042
- add patch from fedora to fix CVE-2021-3575

* Thu Apr 29 2021 daviddavid <daviddavid> 2.4.0-2.mga9
+ Revision: 1720366
- add upstream patch to fix CVE-2021-29338 (mga#28851)

* Wed Dec 30 2020 daviddavid <daviddavid> 2.4.0-1.mga8
+ Revision: 1665546
- new version: 2.4.0, fixes new security issues (mga#27986)
- remove merged upstream patches

* Thu Dec 24 2020 neoclust <neoclust> 2.3.1-8.mga8
+ Revision: 1663282
- Add patches to fix CVE-2020-27841, CVE-2020-27842, CVE-2020-27843, CVE-2020-27845 (mga#27903)

* Mon Dec 14 2020 daviddavid <daviddavid> 2.3.1-7.mga8
+ Revision: 1657415
- backport patches for CVE-2020-27824 and CVE-2020-27823
- backport patch for CVE-2020-27814

* Wed Jul 15 2020 daviddavid <daviddavid> 2.3.1-6.mga8
+ Revision: 1606324
- add upstream patch to fix CVE-2020-15389 (mga#26953)

* Thu Feb 20 2020 umeabot <umeabot> 2.3.1-5.mga8
+ Revision: 1546416
- Mageia 8 Mass Rebuild

* Sun Feb 02 2020 ns80 <ns80> 2.3.1-4.mga8
+ Revision: 1486439
- add upstream patch for CVE-2020-8112 (mga#26162)

* Tue Jan 28 2020 ns80 <ns80> 2.3.1-3.mga8
+ Revision: 1484683
- add upstream patch for CVE-2020-6851 (mga#26141)
+ wally <wally>
- build with new cmake macros

* Wed Nov 27 2019 ns80 <ns80> 2.3.1-2.mga8
+ Revision: 1463076
- add upstream patches for CVE-2019-12973 (mga#25769)

* Tue Apr 02 2019 daviddavid <daviddavid> 2.3.1-1.mga7
+ Revision: 1385409
- new version: 2.3.1
- remove merged upstream patches

* Thu Mar 14 2019 daviddavid <daviddavid> 2.3.0-4.mga7
+ Revision: 1376626
- add upstream patch to fix CVE-2018-14423 (mga#24511)

* Tue Jan 01 2019 luigiwalser <luigiwalser> 2.3.0-3.mga7
+ Revision: 1347885
- add patches from fedora to fix CVE-2018-5785, CVE-2018-6616, CVE-2018-18088
  (also fixes CVE-2017-17479 and CVE-2017-17480)

* Sun Sep 23 2018 umeabot <umeabot> 2.3.0-2.mga7
+ Revision: 1300018
- Mageia 7 Mass Rebuild

* Mon Apr 16 2018 daviddavid <daviddavid> 2.3.0-1.mga7
+ Revision: 1219266
- new version: 2.3.0
- remove merged upstream patches
- add patch to fix shared libraries not getting installed if static libraries are disabled

* Thu Dec 28 2017 luigiwalser <luigiwalser> 2.2.0-3.mga7
+ Revision: 1186297
- add upstream patches via fedora to fix CVE-2017-1404[01]
- rediff patch from opensuse to fix CVE-2017-14039 and CVE-2017-14164

* Sun Aug 20 2017 neoclust <neoclust> 2.2.0-2.mga7
+ Revision: 1142070
- Add 3Patches to fix potential security issues

* Mon Aug 14 2017 neoclust <neoclust> 2.2.0-1.mga7
+ Revision: 1140252
- New version 2.2.0 (mga#21527)

* Fri Feb 10 2017 ns80 <ns80> 2.1.2-3.mga6
+ Revision: 1085260
- add patches for CVE-2016-911[2-8] (mga#20038)

* Fri Dec 09 2016 luigiwalser <luigiwalser> 2.1.2-2.mga6
+ Revision: 1073797
- add patch from fedora to explicitly disable building bundled libraries
- add patches from szukw000 to fix CVE-2016-957[23] and CVE-2016-958[01]

* Tue Oct 04 2016 luigiwalser <luigiwalser> 2.1.2-1.mga6
+ Revision: 1058688
- 2.1.2 (fixes CVE-2016-8332)
- remove upstream CVE patches

* Fri Sep 30 2016 luigiwalser <luigiwalser> 2.1.1-3.mga6
+ Revision: 1057914
- add upstream patch to fix CVE-2016-7445

* Fri Sep 09 2016 luigiwalser <luigiwalser> 2.1.1-2.mga6
+ Revision: 1051144
- add upstream patches to fix CVE-2016-5157 and CVE-2016-7163

* Fri Jul 15 2016 luigiwalser <luigiwalser> 2.1.1-1.mga6
+ Revision: 1042236
- 2.1.1
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Dec 01 2015 luigiwalser <luigiwalser> 2.1.0-6.mga6
+ Revision: 907476
- fix broken pkgconfig files

* Tue Oct 06 2015 luigiwalser <luigiwalser> 2.1.0-5.mga6
+ Revision: 886598
- add patch from fedora to fix CVE-2015-6581

* Tue Sep 15 2015 luigiwalser <luigiwalser> 2.1.0-4.mga6
+ Revision: 879667
- add upstream patch to fix use-after-free issue

* Wed Oct 15 2014 umeabot <umeabot> 2.1.0-3.mga5
+ Revision: 745013
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.1.0-2.mga5
+ Revision: 683219
- Mageia 5 Mass Rebuild

* Wed May 28 2014 luigiwalser <luigiwalser> 2.1.0-1.mga5
+ Revision: 627306
- 2.1.0 (library major is now 7)

* Sat Oct 19 2013 umeabot <umeabot> 2.0.0-4.mga4
+ Revision: 526602
- Mageia 4 Mass Rebuild

* Thu Jun 06 2013 fwang <fwang> 2.0.0-3.mga4
+ Revision: 438304
- drop old obsoletes

* Thu Jun 06 2013 fwang <fwang> 2.0.0-2.mga4
+ Revision: 438296
- update doc dir
- fix build
- imported package openjpeg2

